( cd usr/share/doc/HTML/fr/pikloops ; rm -rf common )
( cd usr/share/doc/HTML/fr/pikloops ; ln -sf /usr/share/doc/HTML/fr/common common )
( cd usr/share/doc/HTML/en/pikloops ; rm -rf common )
( cd usr/share/doc/HTML/en/pikloops ; ln -sf /usr/share/doc/HTML/en/common common )
